==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/SkuLocationInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.SkuLocationInfoArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property extendedLocations
 * @property location
 * @property type
 * @property zoneDetails
 * @property zones
 */
public data class SkuLocationInfoArgs(
    public val extendedLocations: Output<List<String>>? = null,
    public val location: Output<String>,
    public val type: Output<String>? = null,
    public val zoneDetails: Output<List<SkuZoneDetailArgs>>? = null,
    public val zones: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.SkuLocationInfoArgs> {
    override fun toJava(): com.pulumi.azurenative.providerhub.inputs.SkuLocationInfoArgs =
        com.pulumi.azurenative.providerhub.inputs.SkuLocationInfoArgs.builder()
            .extendedLocations(extendedLocations?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .location(location.applyValue({ args0 -> args0 }))
            .type(type?.applyValue({ args0 -> args0 }))
            .zoneDetails(
                zoneDetails?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .zones(zones?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [SkuLocationInfoArgs].
 */
@PulumiTagMarker
public class SkuLocationInfoArgsBuilder internal constructor() {
    private var extendedLocations: Output<List<String>>? = null

    private var location: Output<String>? = null

    private var type: Output<String>? = null

    private var zoneDetails: Output<List<SkuZoneDetailArgs>>? = null

    private var zones: Output<List<String>>? = null

    /**
     * @param value
     */
    @JvmName("jwnntlfswolesgvu")
    public suspend fun extendedLocations(`value`: Output<List<String>>) {
        this.extendedLocations = value
    }

    @JvmName("rvxomhaoddebaofe")
    public suspend fun extendedLocations(vararg values: Output<String>) {
        this.extendedLocations = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("ivqtxiaodjeirlfs")
    public suspend fun extendedLocations(values: List<Output<String>>) {
        this.extendedLocations = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("xqcowwfypdeqyuvk")
    public suspend fun location(`value`: Output<String>) {
        this.location = value
    }

    /**
     * @param value
     */
    @JvmName("emicbwmsraihtjtu")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value
     */
    @JvmName("whlthwabrbtjvosc")
    public suspend fun zoneDetails(`value`: Output<List<SkuZoneDetailArgs>>) {
        this.zoneDetails = value
    }

    @JvmName("rhvyoytnkbhiuqyf")
    public suspend fun zoneDetails(vararg values: Output<SkuZoneDetailArgs>) {
        this.zoneDetails = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("npluyfqkmirsnokb")
    public suspend fun zoneDetails(values: List<Output<SkuZoneDetailArgs>>) {
        this.zoneDetails = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("pqpvnljpbykvdemh")
    public suspend fun zones(`value`: Output<List<String>>) {
        this.zones = value
    }

    @JvmName("mhhqtnhirdcupblc")
    public suspend fun zones(vararg values: Output<String>) {
        this.zones = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("ovxucsujitcaekrb")
    public suspend fun zones(values: List<Output<String>>) {
        this.zones = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("hynpwrqmogklygyr")
    public suspend fun extendedLocations(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.extendedLocations = mapped
    }

    /**
     * @param values
     */
    @JvmName("prpuitsubotpucvo")
    public suspend fun extendedLocations(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.extendedLocations = mapped
    }

    /**
     * @param value
     */
    @JvmName("vmsorhjrariltbqv")
    public suspend fun location(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.location = mapped
    }

    /**
     * @param value
     */
    @JvmName("untdggqingabixqx")
    public suspend fun type(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value
     */
    @JvmName("mmbiidrkbksedoph")
    public suspend fun zoneDetails(`value`: List<SkuZoneDetailArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.zoneDetails = mapped
    }

    /**
     * @param argument
     */
    @JvmName("nulxyyjbaciwwusp")
    public suspend fun zoneDetails(argument: List<suspend SkuZoneDetailArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            SkuZoneDetailArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.zoneDetails = mapped
    }

    /**
     * @param argument
     */
    @JvmName("pfwmkqwlbqgdgemu")
    public suspend fun zoneDetails(vararg argument: suspend SkuZoneDetailArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            SkuZoneDetailArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.zoneDetails = mapped
    }

    /**
     * @param argument
     */
    @JvmName("splgvachmkhpjtyu")
    public suspend fun zoneDetails(argument: suspend SkuZoneDetailArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(SkuZoneDetailArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.zoneDetails = mapped
    }

    /**
     * @param values
     */
    @JvmName("qgsrhlyflupnqmpn")
    public suspend fun zoneDetails(vararg values: SkuZoneDetailArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.zoneDetails = mapped
    }

    /**
     * @param value
     */
    @JvmName("jpmdlrvomtrqvsgd")
    public suspend fun zones(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.zones = mapped
    }

    /**
     * @param values
     */
    @JvmName("rmhogtqtserwrfek")
    public suspend fun zones(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.zones = mapped
    }

    internal fun build(): SkuLocationInfoArgs = SkuLocationInfoArgs(
        extendedLocations = extendedLocations,
        location = location ?: throw PulumiNullFieldException("location"),
        type = type,
        zoneDetails = zoneDetails,
        zones = zones,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/providerhub/kotlin/inputs/SkuLocationInfoArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.providerhub.kotlin.inputs

import com.pulumi.azurenative.providerhub.inputs.SkuLocationInfoArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.String
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 *
 * @property extendedLocations
 * @property location
 * @property type
 * @property zoneDetails
 * @property zones
 */
public data class SkuLocationInfoArgs(
    public val extendedLocations: Output<List<String>>? = null,
    public val location: Output<String>,
    public val type: Output<String>? = null,
    public val zoneDetails: Output<List<SkuZoneDetailArgs>>? = null,
    public val zones: Output<List<String>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.providerhub.inputs.SkuLocationInfoArgs> {
    override fun toJava(): com.pulumi.azurenative.providerhub.inputs.SkuLocationInfoArgs =
        com.pulumi.azurenative.providerhub.inputs.SkuLocationInfoArgs.builder()
            .extendedLocations(extendedLocations?.applyValue({ args0 -> args0.map({ args0 -> args0 }) }))
            .location(location.applyValue({ args0 -> args0 }))
            .type(type?.applyValue({ args0 -> args0 }))
            .zoneDetails(
                zoneDetails?.applyValue({ args0 ->
                    args0.map({ args0 ->
                        args0.let({ args0 ->
                            args0.toJava()
                        })
                    })
                }),
            )
            .zones(zones?.applyValue({ args0 -> args0.map({ args0 -> args0 }) })).build()
}

/**
 * Builder for [SkuLocationInfoArgs].
 */
@PulumiTagMarker
public class SkuLocationInfoArgsBuilder internal constructor() {
    private var extendedLocations: Output<List<String>>? = null

    private var location: Output<String>? = null

    private var type: Output<String>? = null

    private var zoneDetails: Output<List<SkuZoneDetailArgs>>? = null

    private var zones: Output<List<String>>? = null

    /**
     * @param value
     */
    @JvmName("pvjkkhxjlkybswvw")
    public suspend fun extendedLocations(`value`: Output<List<String>>) {
        this.extendedLocations = value
    }

    @JvmName("hlpkfynukiquycfi")
    public suspend fun extendedLocations(vararg values: Output<String>) {
        this.extendedLocations = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("fiegmghhpnownyqc")
    public suspend fun extendedLocations(values: List<Output<String>>) {
        this.extendedLocations = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("qnxjvqjwuwepqakb")
    public suspend fun location(`value`: Output<String>) {
        this.location = value
    }

    /**
     * @param value
     */
    @JvmName("tqhkxvsmgbkbubug")
    public suspend fun type(`value`: Output<String>) {
        this.type = value
    }

    /**
     * @param value
     */
    @JvmName("ixhuduxhxoaryhhx")
    public suspend fun zoneDetails(`value`: Output<List<SkuZoneDetailArgs>>) {
        this.zoneDetails = value
    }

    @JvmName("bjmnjowvsktbinig")
    public suspend fun zoneDetails(vararg values: Output<SkuZoneDetailArgs>) {
        this.zoneDetails = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("phxexhtwawmghonr")
    public suspend fun zoneDetails(values: List<Output<SkuZoneDetailArgs>>) {
        this.zoneDetails = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("yapgftabevrcksaf")
    public suspend fun zones(`value`: Output<List<String>>) {
        this.zones = value
    }

    @JvmName("riluqwfcvfvhmwxk")
    public suspend fun zones(vararg values: Output<String>) {
        this.zones = Output.all(values.asList())
    }

    /**
     * @param values
     */
    @JvmName("nqhjwtvkphitmdxb")
    public suspend fun zones(values: List<Output<String>>) {
        this.zones = Output.all(values)
    }

    /**
     * @param value
     */
    @JvmName("mvoskfdwkuwicetj")
    public suspend fun extendedLocations(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.extendedLocations = mapped
    }

    /**
     * @param values
     */
    @JvmName("kvumbygxgbakgkql")
    public suspend fun extendedLocations(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.extendedLocations = mapped
    }

    /**
     * @param value
     */
    @JvmName("orxdbyxmlyakhfql")
    public suspend fun location(`value`: String) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.location = mapped
    }

    /**
     * @param value
     */
    @JvmName("taxqdoypowaupudq")
    public suspend fun type(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.type = mapped
    }

    /**
     * @param value
     */
    @JvmName("lcuneeripmoglmfk")
    public suspend fun zoneDetails(`value`: List<SkuZoneDetailArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.zoneDetails = mapped
    }

    /**
     * @param argument
     */
    @JvmName("cxfkfmffbeevcdqp")
    public suspend fun zoneDetails(argument: List<suspend SkuZoneDetailArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            SkuZoneDetailArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.zoneDetails = mapped
    }

    /**
     * @param argument
     */
    @JvmName("aupfhkylwrssnalr")
    public suspend fun zoneDetails(vararg argument: suspend SkuZoneDetailArgsBuilder.() -> Unit) {
        val toBeMapped = argument.toList().map {
            SkuZoneDetailArgsBuilder().applySuspend { it() }.build()
        }
        val mapped = of(toBeMapped)
        this.zoneDetails = mapped
    }

    /**
     * @param argument
     */
    @JvmName("usmpqcwcyfnlnegi")
    public suspend fun zoneDetails(argument: suspend SkuZoneDetailArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(SkuZoneDetailArgsBuilder().applySuspend { argument() }.build())
        val mapped = of(toBeMapped)
        this.zoneDetails = mapped
    }

    /**
     * @param values
     */
    @JvmName("ffnjyhibxunsylpl")
    public suspend fun zoneDetails(vararg values: SkuZoneDetailArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.zoneDetails = mapped
    }

    /**
     * @param value
     */
    @JvmName("ekwsnietbefhxvwo")
    public suspend fun zones(`value`: List<String>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.zones = mapped
    }

    /**
     * @param values
     */
    @JvmName("kmotdtkbpjxyuupn")
    public suspend fun zones(vararg values: String) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.zones = mapped
    }

    internal fun build(): SkuLocationInfoArgs = SkuLocationInfoArgs(
        extendedLocations = extendedLocations,
        location = location ?: throw PulumiNullFieldException("location"),
        type = type,
        zoneDetails = zoneDetails,
        zones = zones,
    )
}
